import pygame
import random


class WeatherEffect:
    def __init__(self, screen_width, screen_height):
        self.width = screen_width
        self.height = screen_height
        self.rain_drops = []
        self.cloud_overlay = pygame.Surface(
            (screen_width, screen_height), pygame.SRCALPHA
        )
        self.sunny_overlay = pygame.Surface(
            (screen_width, screen_height), pygame.SRCALPHA
        )

        # Initialize overlays
        self.init_overlays()

    def init_overlays(self):
        # Cloudy overlay (gray)
        pygame.draw.rect(
            self.cloud_overlay, (100, 100, 100, 40), (0, 0, self.width, self.height)
        )

        # Sunny overlay (slight yellow tint)
        pygame.draw.rect(
            self.sunny_overlay, (255, 255, 200, 15), (0, 0, self.width, self.height)
        )

    def update_rain(self):
        # Add new raindrops
        if len(self.rain_drops) < 500:
            self.rain_drops.append(
                [
                    random.randint(0, self.width),
                    random.randint(-10, 0),
                    random.randint(4, 7),  # Speed
                ]
            )

        # Update existing raindrops
        for drop in self.rain_drops[:]:
            drop[1] += drop[2]  # Move down by speed
            if drop[1] > self.height:
                self.rain_drops.remove(drop)

    def draw(self, screen, weather):
        if weather == "rainy":
            # Update and draw rain
            self.update_rain()
            for drop in self.rain_drops:
                pygame.draw.line(
                    screen, (200, 200, 255), (drop[0], drop[1]), (drop[0], drop[1] + 5)
                )
            # Add rain overlay
            screen.blit(self.cloud_overlay, (0, 0))

        elif weather == "cloudy":
            # Just add cloud overlay
            screen.blit(self.cloud_overlay, (0, 0))

        elif weather == "sunny":
            # Add sunny overlay
            screen.blit(self.sunny_overlay, (0, 0))
