import pygame
import math
from config.colors import COLORS


class Player:
    def __init__(self, x: float, y: float):
        self.x = x
        self.y = y
        self.color = COLORS["player"]
        self.radius = 15
        self.speed = 3.0

    def update(self, keys, world):
        """Update player position based on keyboard input"""
        new_x = self.x
        new_y = self.y

        # Calculate movement based on key presses
        if keys[pygame.K_w] or keys[pygame.K_UP]:
            new_y -= self.speed
        if keys[pygame.K_s] or keys[pygame.K_DOWN]:
            new_y += self.speed
        if keys[pygame.K_a] or keys[pygame.K_LEFT]:
            new_x -= self.speed
        if keys[pygame.K_d] or keys[pygame.K_RIGHT]:
            new_x += self.speed

        # Normalize diagonal movement
        if (
            keys[pygame.K_w]
            or keys[pygame.K_UP]
            or keys[pygame.K_s]
            or keys[pygame.K_DOWN]
        ) and (
            keys[pygame.K_a]
            or keys[pygame.K_LEFT]
            or keys[pygame.K_d]
            or keys[pygame.K_RIGHT]
        ):
            new_x = self.x + (new_x - self.x) / math.sqrt(2)
            new_y = self.y + (new_y - self.y) / math.sqrt(2)

        # Check world boundaries
        new_x = max(self.radius, min(world.size - self.radius, new_x))
        new_y = max(self.radius, min(world.size - self.radius, new_y))

        # Check collision with solid objects
        if not world.check_collision(new_x, new_y, self.radius):
            self.x = new_x
            self.y = new_y
