import pygame
from datetime import datetime


class HeaderBar:
    def __init__(self):
        self.height = 30
        self.font = pygame.font.Font(None, 24)
        self.bg_color = (0, 0, 0, 180)
        self.text_color = (255, 255, 255)
        self.weather_colors = {
            "sunny": (255, 223, 0),
            "cloudy": (169, 169, 169),
            "rainy": (0, 191, 255),
        }

    def draw(self, screen, current_time, weather, player_pos, world_size):
        # Create semi-transparent surface
        header_surface = pygame.Surface(
            (screen.get_width(), self.height), pygame.SRCALPHA
        )
        pygame.draw.rect(
            header_surface, self.bg_color, (0, 0, screen.get_width(), self.height)
        )

        # Format time
        time_str = current_time.strftime("%H:%M")

        # Format position as percentage of world size
        pos_x = round((player_pos[0] / world_size) * 100)
        pos_y = round((player_pos[1] / world_size) * 100)

        # Create text elements
        time_text = self.font.render(f"Time: {time_str}", True, self.text_color)
        weather_text = self.font.render(f"Weather: ", True, self.text_color)
        weather_value = self.font.render(
            weather, True, self.weather_colors.get(weather, self.text_color)
        )
        position_text = self.font.render(
            f"Position: {pos_x}%, {pos_y}%", True, self.text_color
        )

        # Draw elements
        screen.blit(header_surface, (0, 0))

        # Layout elements with padding
        padding = 20
        screen.blit(time_text, (padding, 5))

        # Weather (text + value)
        weather_x = time_text.get_width() + padding * 2
        screen.blit(weather_text, (weather_x, 5))
        screen.blit(weather_value, (weather_x + weather_text.get_width(), 5))

        # Position on the right side
        position_x = screen.get_width() - position_text.get_width() - padding
        screen.blit(position_text, (position_x, 5))
