import pygame
from config.settings import WINDOW_SIZE


class DialogBox:
    def __init__(self):
        self.active = False
        self.message = ""
        self.speaker = ""
        self.width = WINDOW_SIZE[0] * 0.8
        self.min_height = 100  # Minimum height
        self.max_height = 250  # Maximum height
        self.x = (WINDOW_SIZE[0] - self.width) / 2
        self.font = pygame.font.Font(None, 32)
        self.small_font = pygame.font.Font(None, 24)
        self.padding = 20
        self.text_color = (255, 255, 255)
        self.bg_color = (0, 0, 0, 180)
        self.line_height = 30

    def calculate_height(self, speaker_text, message_lines):
        """Calculate required height based on content"""
        content_height = (
            self.padding * 2  # Top and bottom padding
            + len(message_lines) * self.line_height  # Message lines
            + 40  # Space for instructions
        )
        return min(max(self.min_height, content_height), self.max_height)

    def show_message(self, speaker, message):
        self.active = True
        self.message = message
        self.speaker = speaker

    def hide(self):
        self.active = False

    def draw(self, screen):
        if not self.active:
            return

        # Calculate speaker text dimensions
        speaker_color = (255, 255, 0) if self.speaker == "You" else self.text_color
        speaker_text = self.font.render(f"{self.speaker}:", True, speaker_color)

        # Word wrap message
        words = self.message.split()
        lines = []
        current_line = []
        for word in words:
            current_line.append(word)
            text = " ".join(current_line)
            if self.font.size(text)[0] > self.width - (
                self.padding * 3 + speaker_text.get_width()
            ):
                current_line.pop()
                lines.append(" ".join(current_line))
                current_line = [word]
        lines.append(" ".join(current_line))

        # Calculate required height
        self.height = self.calculate_height(speaker_text, lines)

        # Update y position based on height
        self.y = WINDOW_SIZE[1] - self.height - 60  # Space for input box

        # Create background
        dialog_surface = pygame.Surface((self.width, self.height), pygame.SRCALPHA)
        pygame.draw.rect(dialog_surface, self.bg_color, (0, 0, self.width, self.height))
        screen.blit(dialog_surface, (self.x, self.y))

        # Draw speaker name
        screen.blit(speaker_text, (self.x + self.padding, self.y + self.padding))

        # Draw all message lines
        for i, line in enumerate(lines):
            text = self.font.render(line, True, self.text_color)
            screen.blit(
                text,
                (
                    self.x + self.padding * 2 + speaker_text.get_width(),
                    self.y + self.padding + i * self.line_height,
                ),
            )

        # Draw chat instructions at bottom of box
        prompt_text = self.small_font.render(
            "Type your message and press Enter, ESC to end conversation",
            True,
            (200, 200, 200),
        )
        screen.blit(prompt_text, (self.x + self.padding, self.y + self.height - 30))
